// Copyright 1996, Marimba Inc. All Rights Reserved.
// Please feel free to use this code as an example.

import java.io.*;
import java.awt.*;
import marimba.gui.*;

/**
 * This is another example based on the UserName example.
 * This time two presentations are displayed in seperate
 * panels. The "ad.gui" presentation is shown at the top
 * of the window, the "username.gui" presentation is shown
 * in the center.
 *
 * @author Arthur van Hoff
 */
public class UserName2 extends Frame {
    PlayerUtil util;
    PlayerPanel top;
    PlayerPanel center;

    /**
     * Constructor
     */
    UserName2() {
	super("example");
	add("North", top = new PlayerPanel());
	util = new PlayerUtil(top);
	util.setPresentation("ad.gui");

	add("Center", center = new PlayerPanel());
	util = new PlayerUtil(center);
	util.setPresentation("username.gui");

	pack();
	show();
    }

    /**
     * Handle events that occur in the presentation.
     */
    public boolean handleEvent(Event evt) {
	if ((evt.id == Event.ACTION_EVENT) && (evt.target instanceof Widget)) {
	    Widget w = (Widget)evt.target;
	    String nm = w.getName();

	    // The user has clicked Ok, or the username was entered.
	    if ("okButton".equals(nm) || "userName".equals(nm)) {
		String name = util.getText("userName").trim();
		if (name.length() > 0) {
		    System.out.println("Name=" + name);
		    System.exit(1);
		}
		util.setText("message", "You have to enter your name first!");
		return true;
	    }

	    // The user has clicked Cancel, exit the application
	    if ("cancelButton".equals(nm)) {
		System.out.println("Cancelled");
		System.exit(0);
		return true;
	    }
	}
	return super.handleEvent(evt);
    }

    /**
     * The main program.
     */
    public static void main(String argv[]) {
	// Create the frame
	new UserName2();
    }
}
